@@ -1,10 +1,12 @@
+from typing import Dict, Union
+
 import dash_html_components as html
 import dash_table
-
 import networkx as nx
 import numpy as np
-import plotly.graph_objs as go
 import pandas as pd
+import plotly.graph_objs as go
+from plotly.graph_objs import Scatter
 
 
 #return icon and text for button
@@ -28,26 +30,49 @@ def create_edges_cytoscape(edges):
         new_elements += [{'data': {'source': edge[0], 'target': edge[1]}}]
     return new_elements
 
-def create_monitor_graph(data,sender_agent = 'Monitor Agent'):
+def create_monitor_graph(
+    data: Union[Dict, np.ndarray], sender_agent: str = "Monitor Agent"
+) -> Scatter:
     """
     Parameters
     ----------
-    data : dict or np.darray
-        The data saved in the MonitorAgent's memory, for each Inputs (Agents) it is connected to.
+    data : dict or np.ndarray
+        The data saved in the MonitorAgent's buffer, for each Inputs (Agents) it is
+        connected to.
     sender_agent : str
         Name of the sender agent
-    **kwargs
-        Custom parameters
+
+    Returns
+    -------
+    Scatter
+        Plotly scatter plot of the data
     """
     if isinstance(data, dict):
-        if 'time' not in data.keys():
-            trace = [go.Scatter(x=np.arange(len(data[key])), y=data[key],mode="lines", name=sender_agent+':'+key) for key in data.keys()]
+        if "time" not in data.keys():
+            trace = [
+                go.Scatter(
+                    x=np.arange(len(data[key])),
+                    y=data[key],
+                    mode="lines",
+                    name=f"{sender_agent}:{key}",
+                )
+                for key in data.keys()
+            ]
         else:
-            trace = [go.Scatter(x=data['time'], y=data[key],mode="lines", name=sender_agent+':'+key) for key in data.keys() if key !='time']
+            trace = [
+                go.Scatter(
+                    x=data["time"],
+                    y=data[key],
+                    mode="lines",
+                    name=f"{sender_agent}:{key}",
+                )
+                for key in data.keys()
+                if key != "time"
+            ]
     else:
         y = data
         x = np.arange(len(y))
-        trace = go.Scatter(x=x, y=y,mode="lines", name=sender_agent)
+        trace = go.Scatter(x=x, y=y, mode="lines", name=sender_agent)
     return trace
 
 def create_params_table(table_name="",data={}, columns=None, **kwargs):
